@@ -201,6 +201,16 @@ YawpConfigDialog::YawpConfigDialog( KConfigDialog * parent, Yawp::Storage * pSto
 	connect(checkCompactPanelLayout, SIGNAL(toggled(bool)), this, SLOT(enableCompactPanelLayout(bool)));
 	connect(radioExtendedTooltip, SIGNAL(toggled(bool)), this, SLOT(enableExtendedTooltipOptions(bool)));
 	
+	QButtonGroup * grpPanelWeather = new QButtonGroup(this);
+	grpPanelWeather->addButton(radioActualTemp);
+	grpPanelWeather->addButton(radioActualIcon);
+	grpPanelWeather->addButton(radioActualBoth);
+	
+	QButtonGroup * grpPanelForecasts = new QButtonGroup(this);
+	grpPanelForecasts->addButton(radioForecastTemp);
+	grpPanelForecasts->addButton(radioForecastIcon);
+	grpPanelForecasts->addButton(radioForecastBoth);
+	
 	//--- RESIZE AND SET MINIMUM SIZE ---
 	QSize minSize( parent->sizeHint() );
 	minSize.setWidth( 650 );
@@ -212,6 +222,48 @@ YawpConfigDialog::YawpConfigDialog( KConfigDialog * parent, Yawp::Storage * pSto
 		KMessageBox::sorry( parent, i18n("Your system does not have any weather-engine. %1 is useless without at least one weatherengine.", QLatin1String(YAWP_NAME)) );
 		btnAddCity->setEnabled( false );
 	}
+	
+	//--- TRIGGER SLOT MODIFIED WHEN CONFIG-DIALOG HAS BEEN CHANGED ---
+	//
+	//--- Settings Page - tab unit systems ---
+	connect(comboDistance, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboPressure, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboTemperature, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboSpeed, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	
+	//--- Settings Page - tab animation ---
+	connect(comboPageAnimation, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboDayformatAnimation, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboDetailAnimation, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboIconAnimation, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(sliderAnimationDuration, SIGNAL(valueChanged(int)), this, SLOT(settingsChanged()));
+	
+	//--- Settings Page - tab update behaviour ---
+	connect(comboInterval,  SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(spinboxStartDelay, SIGNAL(valueChanged(int)), this, SLOT(settingsChanged()));
+	connect(groupBoxTraverseLocationsPeriodically, SIGNAL(clicked()), this, SLOT(settingsChanged()));
+	connect(spinTraverseLocationsTimeout, SIGNAL(valueChanged(int)), this, SLOT(settingsChanged()));
+	
+	//--- Panel Page ---
+	connect(grpPanelWeather, SIGNAL(buttonClicked(int)), this, SLOT(settingsChanged()));
+	connect(grpPanelForecasts, SIGNAL(buttonClicked(int)), this, SLOT(settingsChanged()));
+	connect(comboForecastDays, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkCompactPanelLayout, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkInteractivePanelWeatherIcons, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(radioSimpleTooltip, SIGNAL(clicked()), this, SLOT(settingsChanged()));
+	connect(checkTooltipPreview, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkTooltipSateliteMap, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkTooltipThemeBackground, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	
+	//--- Theme Page ---
+	connect(comboTheme, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkBoxCustomTheme, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkBoxUseCustomBackground, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkBoxUseCustomColor, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboColor, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboLowerColor, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(comboShadowsColor, SIGNAL(currentIndexChanged(int)), this, SLOT(settingsChanged()));
+	connect(checkBoxDisableTextShadows, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
 }
 
 YawpConfigDialog::~YawpConfigDialog()
@@ -258,6 +310,13 @@ YawpConfigDialog::unitsChanged() const
 	return d->bUnitsChanged;
 }
 
+void
+YawpConfigDialog::resetChanges()
+{
+	d->bCityModelChanged = false;
+	d->bCitySettingsChanged = false;
+	d->bUnitsChanged = false;
+}
 
 void
 YawpConfigDialog::setData( const Yawp::ConfigData * data )
@@ -356,6 +415,9 @@ YawpConfigDialog::setData( const Yawp::ConfigData * data )
 	if( data->extendedTooltipOptions.testFlag( Yawp::ThemeBackground ) )
 		checkTooltipThemeBackground->setChecked( true );
 	enableExtendedTooltipOptions( radioExtendedTooltip->isChecked() );
+	
+	//--- unset the apply button ---
+	settingsChanged(false);
 }
 
 void
@@ -502,8 +564,14 @@ YawpConfigDialog::selectCustomThemeFile()
 		KUrl(sDir),
 		"*.svg *.svgz|Scalable Vector Graphics",
 		d->pConfigDlg );
+	
 	if( !filename.isEmpty())
+	{
 		editCustomThemeFile->setText(filename);
+		
+		//--- notify config dialog, that settings has been changed ---
+		settingsChanged();
+	}
 }
 
 void
@@ -546,6 +614,9 @@ YawpConfigDialog::addCity()
 			updateLocationButtons();
 			d->bCitySettingsChanged = true;
 			d->bCityModelChanged = true;
+			
+			//--- notify config dialog, that settings has been changed ---
+			settingsChanged();
 		}
 		else
 		{
@@ -578,6 +649,9 @@ YawpConfigDialog::deleteCity()
 		d->pWeatherModel->removeRows( index.row(), 1 );
 		updateLocationButtons();
 		d->bCityModelChanged = true;
+		
+		//--- notify config dialog, that settings has been changed ---
+		settingsChanged();
 	}
 }
 
@@ -607,7 +681,10 @@ YawpConfigDialog::slotSetTimeZone()
 			cityInfo->setCountryCode( cityInfo->timeZone().countryCode() );
 		d->bCitySettingsChanged = true;
 		d->bCityModelChanged = true;
-	}	
+		
+		//--- notify config dialog, that settings has been changed ---
+		settingsChanged();
+	}
 }
 
 void
@@ -664,5 +741,15 @@ YawpConfigDialog::moveSelectedCity( int offset )
 		cityTableView->setCurrentIndex( index );
 		locationSelected( index );
 		d->bCityModelChanged = true;
+		
+		//--- notify config dialog, that settings has been changed ---
+		settingsChanged();
 	}
 }
+
+void
+YawpConfigDialog::settingsChanged(bool changed)
+{
+	d->pConfigDlg->enableButton(KDialog::Ok, changed);
+	d->pConfigDlg->enableButton(KDialog::Apply, changed);
+}
