@@ -91,6 +91,8 @@ struct WeatherDataProcessor::Private
 	WeatherUtils::Unit convertSpeed2Distance( WeatherUtils::Unit fromSpeed ) const;
 #endif
 
+	QTime getTime(const QString & dateTime) const;
+	
 	void setUVValues( YawpWeather & weather, const QString & sUVIndex, const QString & sUVRating ) const;
 
 	bool isNightTime( QString & sShortDay ) const;
@@ -245,7 +247,7 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 		}
 		else if( !currDate.isValid() )
 		{
-			dTracing() << "Date is not falid -> check " << vTokens;
+			dTracing() << "Date is not valid -> check " << vTokens;
 			QString sShortDay( vTokens.at(0) );
 			bool bNightTime = d->isNightTime( sShortDay );
 
@@ -323,20 +325,9 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 		pDay = cityInfo.days().at(0);
 
 	/*** PARSE SUNRISE AND SUNSET ***/
-	KDateTime sunTime;
-	sunTime = KDateTime::fromString(data.value("Sunrise At").toString(), "%A %B %e, %Y at %H:%M %Z", KSystemTimeZones::timeZones(), true);
-	if( sunTime.isValid() )
-		pDay->setSunrise( sunTime.time() );
-	else
-		pDay->setSunrise( QTime::fromString(data.value("Sunrise At").toString(), "h:m") );
-
-	sunTime = KDateTime::fromString(data.value("Sunset At").toString(), "%A %B %e, %Y at %H:%M %Z", KSystemTimeZones::timeZones(), true);
-	if( sunTime.isValid() )
-		pDay->setSunset( sunTime.time() );
-	else
-		pDay->setSunset(  QTime::fromString(data.value("Sunset At").toString(), "h:m") );
-
-
+	pDay->setSunrise( d->getTime(data.value("Sunrise At").toString()) );
+	pDay->setSunset( d->getTime(data.value("Sunset At").toString()) );
+	
 	YawpWeather & weather
 		= (pDay->hasNightValues() && !cityInfo.isDayTime(pDay) ? pDay->nightWeather() : pDay->weather());
 
@@ -344,6 +335,8 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 		weather.setCurrentIconName( mapConditionIcon( data.value("Condition Icon").toString() ) );
 	if( data.contains("Temperature") )
 		weather.setCurrentTemperature( d->convertTemp(  data.value("Temperature").toString(), fromTempSystem ) );
+	if( data.contains("RealFeel Temperature") )
+		weather.setCurrentRealFeelTemperature( d->convertTemp( data.value("RealFeel Temperature").toString(), fromTempSystem ) );
 	if( data.contains("Dewpoint") )
 		weather.setDewpoint( d->convertTemp( data.value("Dewpoint").toString(), fromDewTempSystem ) );
 	if( data.contains("Visibility") )
@@ -359,6 +352,10 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 	sTmp = data.value("Wind Direction").toString();
 	if( d->checkStringValue( sTmp) )
 		weather.setWindDirection( sTmp );
+	if (data.contains("Windchill"))
+		weather.setWindChill(data.value("Windchill").toInt());
+	if (data.contains("Wind Gust"))
+		weather.setWindGust( d->convertSpeed( data.value("Wind Gust").toString(),  fromSpeedSystem ) );
 	
 	weather.setWindShortText( d->createWindShortText(weather) );
 	weather.setPressureShortText( d->createPressureText(weather) );
@@ -386,8 +383,9 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 		{
 			break;
 		}
-		else if( pDay->date() == yesterday && pDay->sunrise().isValid() &&
-		    QTime::currentTime() < pDay->sunrise() )
+		else if( pDay->date() == yesterday &&
+		         pDay->sunrise().isValid() &&
+		         QTime::currentTime() < pDay->sunrise() )
 		{
 			break;
 		}
@@ -422,7 +420,6 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 				cityInfo.setSatelliteImage( img );
 		}
 	}
-	
 	return true;
 }
 
@@ -595,6 +592,30 @@ WeatherDataProcessor::setForecastSun( YawpDay & day, const QString & sValue ) co
 	return false;
 }
 
+/* The string for sunrise and sunset looks like this: "Monday December 12, 2011 at 15:57"
+ * IONs will return a english text always, no matter, which languages has been chosen.
+ * In KDE 4.7.2 - I noticed KDE is not able to parse this string, when languages is not english!?
+ * Therefore I extract the time from the string and parse this part only.
+ */
+QTime
+WeatherDataProcessor::Private::getTime(const QString & dateTime) const
+{
+	QTime time;
+	int startPos = dateTime.indexOf("at");
+	
+	if (startPos > 0)
+	{
+		startPos += 3;
+		int endPos = dateTime.indexOf(' ', startPos + 1);
+		if (endPos < 0)
+			endPos = dateTime.length();
+		
+		QString timeString = dateTime.mid(startPos, endPos - startPos);
+		time = QTime::fromString(timeString, "h:mm");
+	}
+	return time;
+}
+
 void
 WeatherDataProcessor::Private::setUVValues( YawpWeather & weather,
                                             const QString & sUVIndex,
