@@ -18,13 +18,8 @@
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 \*************************************************************************/
 
-/*	The weatherserviceclass controls all locations and
- *  interacts with the dataengine in order to keep all locations up to date.
- *
- *  QImage objects can be passed around by value since the QImage class uses implicit data sharing.
- *  QImage objects can also be streamed and compared.
- *  Thanks to Qt we don't have to take care of controlling the satellite image
- *  and can store an image in each location.
+/* The weatherserviceclass controls all locations and
+ * interacts with the dataengine in order to keep all locations up to date.
  */
 
 
@@ -54,6 +49,7 @@
 #define COL_PROVIDER       1
 #define COL_UPDATETIME     2
 #define COL_TIMEZONE       3
+#define COL_PROVIDERCODE   4
 
 
 struct tCityData
@@ -194,7 +190,7 @@ int
 WeatherServiceModel::columnCount( const QModelIndex & parent ) const
 {
 	Q_UNUSED(parent)
-	return 4;
+	return 5;
 }
 
 QVariant
@@ -211,6 +207,7 @@ WeatherServiceModel::headerData( int section,
 		case COL_PROVIDER:      var = i18n("Provider"); break;
 		case COL_UPDATETIME:    var = i18n("Last update"); break;
 		case COL_TIMEZONE:      var = i18n("Timezone"); break;
+		case COL_PROVIDERCODE:  var = i18n("Provider code"); break;
 		}
 		return var;
 	}
@@ -250,6 +247,10 @@ WeatherServiceModel::data( const QModelIndex & index, int role ) const
 		case COL_TIMEZONE:
 			var = (pCity->timeZone().isValid() ? pCity->timeZone().name() : "?");
 			break;
+			
+		case COL_PROVIDERCODE:
+			var = pCity->extraData();
+			break;
 		}
 	}
 	else if( role == Qt::DecorationRole )
@@ -314,7 +315,7 @@ WeatherServiceModel::addCity( const CityWeather & cityInfo, int index )
 			return -1;
 		}
 	}
-
+	
 	tCityData * pData = d->createNewData( cityInfo );
 	if( index < 0 || index >= d->vLocations.count() )
 		index = d->vLocations.count();
@@ -442,13 +443,11 @@ WeatherServiceModel::copyCities( const WeatherServiceModel & other )
 CityWeather *
 WeatherServiceModel::getCityInfo( int index ) const
 {
-//	dStartFunct();
 	CityWeather * pCity = NULL;
 	if( index >= 0 && index < d->vLocations.count() )
 	{
 		pCity = &d->vLocations.at(index)->cityInfo;
 	}
-//	dEndFunct();
 	return pCity;
 }
 
@@ -511,11 +510,8 @@ WeatherServiceModel::dataUpdated( const QString & sourceName, const Plasma::Data
 		bool bUpdateFinished(true);
 		if( d->manualUpdateTimeoutTimer.isActive() )
 		{
-//			dDebug() << "Manual Update started: " << d->manualUpdateStartDatetime;
 			foreach( tCityData * pData, d->vLocations )
 			{
-//				dDebug() << pData->cityInfo.city() << pData->cityInfo.lastUpdate();
-
 				if( pData->cityInfo.lastUpdate() < d->manualUpdateStartDatetime )
 				{
 					bUpdateFinished = false;
@@ -543,7 +539,6 @@ WeatherServiceModel::timerEvent( QTimerEvent * e )
 
 		emit cityUpdated( d->updateFlags );
 		d->updateFlags = NormalUpdate;
-		dDebug() << "timerEvent...";
 	}
 	else
 		QAbstractTableModel::timerEvent( e );
@@ -637,16 +632,24 @@ WeatherServiceModel::Private::createNewData( const CityWeather & otherCity ) con
 void
 WeatherServiceModel::Private::loadCachedValues( CityWeather & cityInfo )
 {
-	// if we have an engine, than try to load cached values
 	if( pDataProcessor )
 	{
-		Plasma::DataEngine * pEngine = pStorage->ionListModel()->engine();
 		QString sourceString = getSourceString( cityInfo );
-		Plasma::DataEngine::Data data = pEngine->query( sourceString );
+		Plasma::DataEngine * pEngine = pStorage->engine();
+		Plasma::DataEngine::Data data;
 		
-		if( !data.isEmpty() )
-			pDataProcessor->updateLocation( cityInfo, data );
-		else
+		if (pEngine != 0)
+			data = pEngine->query( sourceString );
+
+		if (data.isEmpty())
+		{
+			dTracing() << "Load cached data for" << cityInfo.city();
 			pDataProcessor->loadData( cityInfo );
+		}
+		else
+		{
+			dTracing() << "Update location for" << cityInfo.city();
+			pDataProcessor->updateLocation( cityInfo, data );
+		}
 	}
 }
