@@ -85,6 +85,10 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	  m_pAppletPainter(0),
 	  m_iIdPendingEngineConnection(-1),
 	  m_iIdTraverseLocations(-1)
+#if KDE_IS_VERSION(4,7,95)
+	  ,	// <--- this comma seperates the following member variable from the previous one
+	  m_panelDesktopInterface(0)
+#endif
 {
 	Q_INIT_RESOURCE(yawpresource);
 	dStartFunct() << "============================================";
@@ -171,6 +175,10 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	m_configData.bTraverseLocationsPeriodically = false;
 	m_configData.iTraverseLocationTimeout = 30;
 
+	// specifies the order of the shown properties in details page
+	// when a provider do not support a property, this one will be skipped.
+	// Remove a property you do not want to see on details page or change
+	// the order as you like.
 	m_configData.vDetailsPropertyRankingList
 		<< Yawp::WeatherDescription
 		<< Yawp::SunriseSunset
@@ -292,6 +300,7 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 
 	setHasConfigurationInterface(true);
 	setAspectRatioMode(Plasma::KeepAspectRatio);
+	setPopupIcon(QIcon());
 	setPassivePopup(true);
 	
 	resize(273, 255);	// set a fixed initial size that fits the desktop mode. We simply suppose we are always in desktop-mode.
@@ -304,8 +313,13 @@ YaWP::~YaWP()
 	dStartFunct();
 	Plasma::ToolTipManager::self()->clearContent(this);
 
+#if KDE_IS_VERSION(4,7,95)
+	if (m_panelDesktopInterface != 0)
+		m_panelDesktopInterface->deleteLater();
+#else
 	destroyExtenderItem();
-
+#endif
+	
 	if (hasFailedToLaunch())
 	{
 		// Do some cleanup here
@@ -334,8 +348,12 @@ YaWP::init()
 
 	loadConfig();
 	loadCustomTheme();
-	initAppletPainter();
 
+#if KDE_IS_VERSION(4,7,95)
+	createDesktopInterface();
+#endif
+	initAppletPainter();
+	
 	//--- just 4 debug ---
 /*	CityWeather dummyCity1;
 	dummyCity1.setProvider(QString("accuweather"));
@@ -828,6 +846,8 @@ YaWP::mousePressEvent(QGraphicsSceneMouseEvent * event)
 void
 YaWP::timerEvent(QTimerEvent * event)
 {
+	Plasma::PopupApplet::timerEvent(event);
+	
 	if (event->timerId() == m_iIdPendingEngineConnection)
 	{
 		stopPendingEngineConnection();
@@ -840,7 +860,6 @@ YaWP::timerEvent(QTimerEvent * event)
 		int iSelectedCityIndex = (m_configData.iCityIndex + 1) % m_pWeatherModel->rowCount();
 		m_pAppletPainter->initCityChangeAnimation(iSelectedCityIndex);
 	}
-	Plasma::Applet::timerEvent(event);
 }
 
 void
@@ -1069,14 +1088,22 @@ YaWP::initAppletPainter()
 
 		if (form == Plasma::Horizontal || form == Plasma::Vertical)
 		{
-			m_pAppletPainter = new PanelPainter(this, &m_configData, &m_stateMachine, form);
+			PanelPainter * panelPainter = new PanelPainter(this, &m_configData, &m_stateMachine, form);
+			m_pAppletPainter = panelPainter;
+#if KDE_IS_VERSION(4,7,95)
+			panelPainter->setPopupPainter(m_panelDesktopInterface->desktopPainter());
+#else
 			createExtenderItem();
+#endif
 			createPanelTooltip();
 		}
 		else
 		{
 			m_pAppletPainter = new DesktopPainter(this, &m_configData, &m_stateMachine);
+#if KDE_IS_VERSION(4,7,95)
+#else
 			destroyExtenderItem();
+#endif
 			Plasma::ToolTipManager::self()->clearContent(this);
 		}
 		connect(m_pWeatherModel, SIGNAL(isBusy(bool)), m_pAppletPainter, SLOT(setBusy(bool)));
@@ -1093,6 +1120,24 @@ YaWP::initAppletPainter()
 	m_pAppletPainter->setupAnimationTimeLine();
 }
 
+#if KDE_IS_VERSION(4,7,95)
+
+void
+YaWP::createDesktopInterface()
+{
+	m_panelDesktopInterface = new PanelDesktopInterface(&m_configData, &m_stateMachine);
+	m_panelDesktopInterface->setSvg(&m_svg);
+	m_panelDesktopInterface->setCustomSvg(&m_customSvg);
+	m_panelDesktopInterface->setupAnimationTimeLine();
+
+	m_panelDesktopInterface->setMinimumSize(QSizeF(100, 93));
+	m_panelDesktopInterface->setPreferredSize(273, 255);
+
+	connect( m_pWeatherModel, SIGNAL(isBusy(bool)), m_panelDesktopInterface, SLOT(setBusy(bool)) );
+	setGraphicsWidget(m_panelDesktopInterface);
+}
+
+#else
 
 void
 YaWP::createExtenderItem()
@@ -1169,6 +1214,7 @@ YaWP::destroyExtenderItem()
 		extender()->item(PANEL_DESKTOP_INTERFACE_NAME)->deleteLater();
 	}
 }
+#endif
 
 void
 YaWP::createPanelTooltip()
