@@ -23,6 +23,7 @@
 
 //--- LOCAL CLASSES ---
 #include "painter/abstractpainter.h"
+#include "paneldesktopinterface.h"
 #include "statemachine.h"
 #include "pageanimator.h"
 #include "weatherservice.h"
@@ -93,7 +94,11 @@ public:
 protected:
 	virtual void mousePressEvent( QGraphicsSceneMouseEvent * event );
 	virtual void timerEvent ( QTimerEvent * event );
+
+#if KDE_IS_VERSION(4,7,95)
+#else
 	virtual void initExtenderItem(Plasma::ExtenderItem * item);
+#endif
 
 private slots:
 	void about() const;
@@ -125,9 +130,13 @@ private:
 	void updateCitySubMenu();
 	
 	void initAppletPainter();
-	
+
+#if KDE_IS_VERSION(4,7,95)
+	void createDesktopInterface();
+#else
 	void createExtenderItem();
 	void destroyExtenderItem();
+#endif
 	
 	void createPanelTooltip();
 
@@ -178,6 +187,10 @@ private:
 	
 	// timer-id for changing city periodically
 	int                          m_iIdTraverseLocations;
+	
+#if KDE_IS_VERSION(4,7,95)
+	PanelDesktopInterface      * m_panelDesktopInterface;
+#endif
 };
 
 #endif
