@@ -39,9 +39,12 @@ struct YawpWeather::Private
 	short       iWindSpeed;
 	QString     sWindDirection;
 	QString     sWindShortText;
+	short       iWindChill;
+	short       iWindGust;
 	short       iHumidity;
 
 	short       iCurrentTemperature;
+	short       iCurrentRealFeelTemperature;
 	short       iTemperatureHigh;
 	short       iTemperatureLow;
 	short       iTemperatureRealFeelHigh;
@@ -83,10 +86,13 @@ YawpWeather::clear()
 	d->iWindSpeed                = SHRT_MAX;
 	d->sWindDirection.clear();
 	d->sWindShortText.clear();
+	d->iWindChill                = SHRT_MAX;
+	d->iWindGust                 = SHRT_MAX;
 
 	d->iHumidity                 = SHRT_MAX;
 
 	d->iCurrentTemperature       = SHRT_MAX;
+	d->iCurrentRealFeelTemperature = SHRT_MAX;
 	d->iTemperatureHigh          = SHRT_MAX;
 	d->iTemperatureLow           = SHRT_MAX;
 	d->iTemperatureRealFeelHigh  = SHRT_MAX;
@@ -141,6 +147,18 @@ YawpWeather::windDirection() const { return d->sWindDirection; }
 void
 YawpWeather::setWindDirection(const QString & direction) { d->sWindDirection = direction; }
 
+short
+YawpWeather::windChill() const { return d->iWindChill; }
+
+void
+YawpWeather::setWindChill(short windChill) { d->iWindChill = windChill; }
+
+short
+YawpWeather::windGust() const { return d->iWindGust; }
+
+void
+YawpWeather::setWindGust(short windGust) { d->iWindGust = windGust; }
+
 short
 YawpWeather::humidity() const { return d->iHumidity; }
 
@@ -153,6 +171,12 @@ YawpWeather::currentTemperature() const { return d->iCurrentTemperature; }
 void
 YawpWeather::setCurrentTemperature(short current) { d->iCurrentTemperature = current; }
 
+short
+YawpWeather::currentRealFeelTemperature() const { return d->iCurrentRealFeelTemperature; }
+
+void
+YawpWeather::setCurrentRealFeelTemperature(short current) { d->iCurrentRealFeelTemperature = current; }
+
 short
 YawpWeather::lowTemperature() const { return d->iTemperatureLow; }
 
@@ -492,6 +516,8 @@ CityWeather::debug_PrintCityWeather( const CityWeather & cityInfo )
 
 			dDebug() << QString("   %1current temp  = %2")
 				.arg(sPrefix).arg(weather.currentTemperature()).toUtf8().constData();
+			dDebug() << QString("   %1current real feel temp = %2")
+				 .arg(sPrefix).arg(weather.currentRealFeelTemperature()).toUtf8().constData();
 			dDebug() << QString("   %1current icon  = %2")
 				.arg(sPrefix).arg(weather.currentIconName()).toUtf8().constData();
 
@@ -513,6 +539,10 @@ CityWeather::debug_PrintCityWeather( const CityWeather & cityInfo )
 				.arg(sPrefix).arg(weather.windSpeed()).toUtf8().constData();
 			dDebug() << QString("   %1windDirection = %2")
 				.arg(sPrefix).arg(weather.windDirection()).toUtf8().constData();
+			dDebug() << QString("   %1wind chill    = %2")
+				.arg(sPrefix).arg(weather.windChill()).toUtf8().constData();
+			dDebug() << QString("   %1wind gust    = %2")
+				.arg(sPrefix).arg(weather.windGust()).toUtf8().constData();
 
 			dDebug() << QString("  %1property text lines = %2")
 				.arg(sPrefix).arg(weather.propertyTextLines().count()).toUtf8().constData();
