@@ -64,12 +64,19 @@ public:
 	void setWindDirection(const QString & direction);
 	const QString & windShortText() const;
 	void setWindShortText(const QString & text);
+	short windChill() const;
+	void setWindChill(short windchill);
+	short windGust() const;
+	void setWindGust(short windGust);
 
 	short humidity() const;
 	void setHumidity(short humidity);
 
 	short currentTemperature() const;
 	void setCurrentTemperature(short current);
+	
+	short currentRealFeelTemperature() const;
+	void setCurrentRealFeelTemperature(short current);
 
 	short lowTemperature() const;
 	void setLowTemperature(short low);
