@@ -196,7 +196,7 @@ echo "UNITTESTS: $UNITTESTS"
 echo "LOGLEVEL: $LOGLEVEL"
 echo "LOGFILE: $LOGFILE"
 echo
-echo "Prepare build directory..."
+echo -e $MESSAGE"Prepare build directory..."$NORMALTEXT
 rm --recursive --force build CMakeFiles CMakeTmp CMakeCache.txt cmake_install.cmake cmake_uninstall.cmake CTestTestfile.cmake Makefile
 
 if [ ! -d build  ]; then
@@ -210,7 +210,7 @@ if [ $ret -ne 0 ]; then
 fi
 
 echo 
-echo "Run cmake..."
+echo -e $MESSAGE"Run cmake..."$NORMALTEXT
 cd build
 cmake -DCMAKE_INSTALL_PREFIX=`kde4-config --prefix` $DEBUG $UNITTESTS $LOGFILE $LOGLEVEL ..
 
@@ -221,11 +221,11 @@ if [ $ret -ne 0 ]; then
 fi
 
 echo
-echo "Run make clean..."
+echo -e $MESSAGE"Run make clean..."$NORMALTEXT
 make clean
 
 echo
-echo "Compile..."
+echo -e $MESSAGE"Compile..."$NORMALTEXT
 if [ -z "$JOB_COUNT" ]; then
 	## Try to determine the number of processor-cores.
 	JOB_COUNT=1
