@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007-2008 by Shawn Starr <shawn.starr@rogers.com>       *
+ *   Copyright (C) 2009-2011 by  Ulf Kreißig <udev@gmx.net>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,25 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
  ***************************************************************************/
 
-/*************************************************************************\
-*   Copyright (C) 2009 by Ulf Kreissig                                    *
-*   udev@gmx.net                                                          *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
-\*************************************************************************/
+/*  The source code of this weather engine based on source code
+ *  of KDE's standard weather engines written by Shawn Starr.
+ */
 
 //--- LOCAL ---
 #include "../config.h"
@@ -81,6 +66,13 @@ struct AccuWeatherIon::Private
 #if KDE_IS_VERSION(4,4,80)
 	QStringList                       sourcesToReset;
 #endif
+	
+	QByteArray getImageUrl( const QString & sLocationCode, const QString & state ) const;
+
+	void removeAllImages();
+	void removeImageDataAttachedWeatherData(ImageData * pImageData);
+	
+	void printJobStatistics() const;
 };
 
 AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
@@ -271,16 +263,10 @@ AccuWeatherIon::cleanup()
 	for( itImg = d->vImageJobs.begin(); itImg != d->vImageJobs.end(); ++itImg )
 	{
 		itImg.key()->kill( KJob::Quietly );
+		
 		ImageData * pImageData = itImg.value();
-
-		/* Delete all pending WeatherDatas as well. */
-		QList<WeatherData*>::iterator itWeather = pImageData->vWeatherSources.begin();
-		for( ; itWeather != pImageData->vWeatherSources.end(); ++itWeather )
-		{
-			WeatherData * pWeather = *itWeather;
-			qDeleteAll( pWeather->vForecasts.begin(), pWeather->vForecasts.end() );
-			delete pWeather;
-		}
+		d->removeImageDataAttachedWeatherData(pImageData);
+		
 		delete pImageData;
 	}
 	/* contains the same values than vImageJobs, but the key differs so that we will find it by url. */
@@ -315,8 +301,8 @@ AccuWeatherIon::findPlace( const QString & location, const QString & source )
 //		pJob->addMetaData("cookies", "none"); // Disable displaying cookies
 
 		struct XmlJobData * pXmlData = new XmlJobData;
-		pXmlData->sLocation = location;
-		pXmlData->sSource = source;
+		pXmlData->location = location;
+		pXmlData->source = source;
 
 		d->vSearchJobs.insert( pJob, pXmlData );
 		d->vActiveJobs.insert( QString("%1|%2").arg(location).arg(ActionValidate), pJob );
@@ -348,20 +334,20 @@ AccuWeatherIon::setup_slotJobFinished( KJob * job )
 
 	if( job->error() != 0 )
 	{
-		setData( pXmlData->sSource, ActionValidate, QString("%1|timeout").arg(IonName) );
-		disconnectSource( pXmlData->sSource, this );
+		setData( pXmlData->source, ActionValidate, QString("%1|timeout").arg(IonName) );
+		disconnectSource( pXmlData->source, this );
 		dWarning() << job->errorString();
 	}
 	else
 	{
-		readSearchXmlData( pXmlData->sLocation, pXmlData->sSource, pXmlData->xmlReader );
+		readSearchXmlData( pXmlData->location, pXmlData->source, pXmlData->xmlReader );
 	}
 	d->vSearchJobs.remove( job );
-	d->vActiveJobs.remove( QString("%1|%2").arg(pXmlData->sLocation).arg(ActionValidate) );
+	d->vActiveJobs.remove( QString("%1|%2").arg(pXmlData->location).arg(ActionValidate) );
 	job->deleteLater();
 	delete pXmlData;
 
-//	dDebug() << "Search Jobs: " << d->vSearchJobs.count();
+	d->printJobStatistics();
 	dEndFunct();
 }
 
@@ -450,17 +436,13 @@ AccuWeatherIon::getWeatherXmlData( const QString & location, const QString & loc
 //		pJob->addMetaData("cookies", "none"); // Disable displaying cookies
 
 		struct XmlJobData * pXmlData = new XmlJobData;
-		pXmlData->sSource = source;
-		pXmlData->sLocationCode = locationCode;
-		pXmlData->sLocation = location;
-		pXmlData->imageUrl = getImageUrl( locationCode );
+		pXmlData->source = source;
+		pXmlData->locationCode = locationCode;
+		pXmlData->location = location;
 
 		d->vObservationJobs.insert( pJob, pXmlData);
 		d->vActiveJobs.insert( QString("%1|%2").arg(locationCode).arg(ActionWeather), pJob );
 		
-		if( !pXmlData->imageUrl.isEmpty() )
-			connectWithImageData( pXmlData->imageUrl );
-
 		connect( pJob, SIGNAL(data(KIO::Job *, const QByteArray &)), this,
 			SLOT(slotDataArrived(KIO::Job *, const QByteArray &)) );
 		connect( pJob, SIGNAL(result(KJob *)), this, SLOT(slotJobFinished(KJob *)));
@@ -502,32 +484,33 @@ AccuWeatherIon::slotJobFinished( KJob * pJob )
 	XmlJobData * pXmlData = d->vObservationJobs[pJob];
 	ImageData  * pImageData = NULL;
 
-	if( !pXmlData->imageUrl.isEmpty() && d->vImageData.contains(pXmlData->imageUrl) )
-		pImageData = d->vImageData[pXmlData->imageUrl];
-
 	if( pJob->error() != 0 )
 	{
-		dWarning()  << pXmlData->sSource << pJob->errorString();
-
-		//--- we still have to unregister from the image data ---
-		if( pImageData )
-			pImageData->iLocationCounter -= 1;
-		else
-			dWarning() << pXmlData->sSource << "xml-job has no image-data!";
+		dWarning()  << pXmlData->source << pJob->errorString();
 	}
 	else
 	{
-		dDebug() << pXmlData->sSource << "xml-job has successfully completed";
+		dDebug() << pXmlData->source << "xml-job has successfully completed";
 
 		WeatherData * pWeather = new WeatherData;
-		pWeather->city = pXmlData->sLocation;
-		pWeather->source = pXmlData->sSource;
-		pWeather->iUtcHourOffset = 0;
-		pWeather->iUtcMinutesOffset = 0;
+		pWeather->city = pXmlData->location;
+		pWeather->source = pXmlData->source;
+		pWeather->utcHourOffset = 0;
+		pWeather->utcMinutesOffset = 0;
 
 		readWeatherXmlData( pXmlData->xmlReader, *pWeather );
+		
+		// Download the satellite image
+		QByteArray imageUrl = d->getImageUrl( pXmlData->locationCode, pWeather->state );
+		if( !imageUrl.isEmpty() )
+		{
+			connectWithImageData( imageUrl );
+			
+			if( !imageUrl.isEmpty() && d->vImageData.contains(imageUrl) )
+				pImageData = d->vImageData[imageUrl];
+		}
 
-		if (pImageData && !pImageData->bReady)
+		if (pImageData && !pImageData->ready)
 		{
 			//  The attached image data has not been downloaded yet, so we store the weather data
 			//  to the pending update sources.
@@ -539,26 +522,18 @@ AccuWeatherIon::slotJobFinished( KJob * pJob )
 			updateWeatherSource( *pWeather, pImageData );
 			qDeleteAll( pWeather->vForecasts.begin(), pWeather->vForecasts.end() );
 			delete pWeather;
-			
-			if (pImageData)
-				pImageData->iLocationCounter -= 1;
 		}
 	}
-	//--- when we do not need the image anymore and the image job has been completed remove the image data ---
-	if( pImageData && pImageData->bReady && pImageData->iLocationCounter <= 0 )
-	{
-		d->vImageData.remove( pXmlData->imageUrl );
-		delete pImageData;
-	}
 
 	d->vObservationJobs.remove( pJob );
-	d->vActiveJobs.remove( QString("%1|%2").arg(pXmlData->sLocationCode).arg(ActionWeather) );
+	d->vActiveJobs.remove( QString("%1|%2").arg(pXmlData->locationCode).arg(ActionWeather) );
 	pJob->deleteLater();
 	delete pXmlData;
 
-	dDebug() << "Observation Reader: " << d->vObservationJobs.count();
-	dDebug() << "Image Jobs: " << d->vImageJobs.count();
-	dDebug() << "Image Data: " << d->vImageData.count();
+	//--- remove all images when we do not have an active observation and image job ---
+	d->removeAllImages();
+
+	d->printJobStatistics();
 	dEndFunct();
 }
 
@@ -625,24 +600,24 @@ AccuWeatherIon::readUnits( QXmlStreamReader & xml, WeatherData & weather )
 		{
 //			dDebug() << xml.name().toString();
 			if( xml.name().compare("temp") == 0 )
-				weather.iTempSystem = ( xml.readElementText().compare("F") == 0 ? FAHRENHEIT : CELSIUS );
+				weather.tempSystem = ( xml.readElementText().compare("F") == 0 ? FAHRENHEIT : CELSIUS );
 			else if( xml.name().compare("speed") == 0 )
-				weather.iSpeedSystem = ( xml.readElementText().compare("MPH") == 0 ? MPH : KPH );
+				weather.speedSystem = ( xml.readElementText().compare("MPH") == 0 ? MPH : KPH );
 			else if( xml.name().compare("dist") == 0 )
 			{
 				QString sDist = xml.readElementText();
 				if( sDist.compare("MI") == 0 )
-					weather.iDistanceSystem = MILES;
+					weather.distanceSystem = MILES;
 				else
-					weather.iDistanceSystem = 0;
+					weather.distanceSystem = 0;
 			}
 			else if( xml.name().compare("pres") == 0 )
 			{
 				QString sPres = xml.readElementText();
 				if( sPres.compare("IN") == 0 )
-					weather.iPressureSystem = INCHESHG;
+					weather.pressureSystem = INCHESHG;
 				else
-					weather.iPressureSystem = 0;
+					weather.pressureSystem = 0;
 			}
 			else if( xml.name().compare("prec") == 0 )
 			{
@@ -666,9 +641,9 @@ AccuWeatherIon::readLocal( QXmlStreamReader & xml, WeatherData & weather )
 		else if( xml.isStartElement() )
 		{
 			if( xml.name().compare("lat") == 0 )
-				weather.sLatitude = xml.readElementText();
+				weather.latitude = xml.readElementText();
 			else if( xml.name().compare("lon") == 0 )
-				weather.sLongitude = xml.readElementText();
+				weather.longitude = xml.readElementText();
 /*			else if( xml.name().compare("time") == 0 )
 				weather.sObservationPeriode = xml.readElementText();
 */			else if( xml.name().compare("timeZone") == 0 )
@@ -677,10 +652,14 @@ AccuWeatherIon::readLocal( QXmlStreamReader & xml, WeatherData & weather )
 				int iPos( sTimeZone.indexOf(QChar(':')) );
 				if( iPos > 0 )
 				{
-					weather.iUtcHourOffset = sTimeZone.left(iPos).toShort();
-					weather.iUtcMinutesOffset = sTimeZone.right(sTimeZone.length()-iPos-1).toShort();
+					weather.utcHourOffset = sTimeZone.left(iPos).toShort();
+					weather.utcMinutesOffset = sTimeZone.right(sTimeZone.length()-iPos-1).toShort();
 				}
+				else
+					weather.utcHourOffset = sTimeZone.toShort();
 			}
+			else if (xml.name().compare("state") == 0)
+				weather.state = xml.readElementText();
 		}
 	}
 	if( xml.hasError() )
@@ -706,7 +685,7 @@ AccuWeatherIon::readCurrentConditions( QXmlStreamReader & xml, WeatherData & wea
 			else if( xml.name().compare("temperature") == 0 )
 				weather.temperature = xml.readElementText();
 			else if( xml.name().compare("realfeel") == 0 )
-				weather.realfeel = xml.readElementText();
+				weather.realfeelTemperature = xml.readElementText();
 			else if( xml.name().compare("humidity") == 0 )
 				weather.humidity = xml.readElementText();
 			else if( xml.name().compare("weathertext") == 0 )
@@ -776,12 +755,12 @@ AccuWeatherIon::readForecastConditions( QXmlStreamReader & xml, ForecastDay & fo
 			else if( xml.name().compare("daytime") == 0 )
 			{
 				dTracing() << "Parse day time values:";
-				readWeatherConditions( xml, forecast.DayTime );
+				readWeatherConditions( xml, forecast.dayTime );
 			}
 			else if( xml.name().compare("nighttime") == 0 )
 			{
 				dTracing() << "Parse night time values:";
-				readWeatherConditions( xml, forecast.NightTime );
+				readWeatherConditions( xml, forecast.nightTime );
 			}
 		}
 	}
@@ -847,11 +826,11 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 	removeAllData( weather.source );	// clear the old values
 	setData(weather.source, Data());	// start the update timer
 
-	setData( weather.source, "Dewpoint Unit", QString::number(weather.iTempSystem) );
-	setData( weather.source, "Temperature Unit", QString::number(weather.iTempSystem) );
-	setData( weather.source, "Wind Speed Unit",  QString::number(weather.iSpeedSystem) );
-	setData( weather.source, "Wind Gust Unit", QString::number(weather.iSpeedSystem) );
-	setData( weather.source, "Visibility Unit", QString::number(weather.iDistanceSystem) );
+	setData( weather.source, "Dewpoint Unit", QString::number(weather.tempSystem) );
+	setData( weather.source, "Temperature Unit", QString::number(weather.tempSystem) );
+	setData( weather.source, "Wind Speed Unit",  QString::number(weather.speedSystem) );
+	setData( weather.source, "Wind Gust Unit", QString::number(weather.speedSystem) );
+	setData( weather.source, "Visibility Unit", QString::number(weather.distanceSystem) );
 
 	setData( weather.source, "Place", weather.city );
 	setData( weather.source, "Condition Icon", stringConverter(weather.weathericon) );
@@ -862,9 +841,10 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 	if( !weather.pressure.isEmpty() )
 	{
 		setData( weather.source, "Pressure Tendency", stringConverter(weather.pressureTendency) );
-		setData( weather.source, "Pressure Unit", QString::number(weather.iPressureSystem) );
+		setData( weather.source, "Pressure Unit", QString::number(weather.pressureSystem) );
 	}
 	setData( weather.source, "Temperature", stringConverter(weather.temperature) );
+	setData( weather.source, "RealFeel Temperature", stringConverter(weather.realfeelTemperature) );
 	setData( weather.source, "UV Index", stringConverter(weather.uvIndex) );
 	setData( weather.source, "UV Rating", stringConverter(weather.uvRating) );
 	setData( weather.source, "Visibility", stringConverter(weather.visibility) );
@@ -873,10 +853,10 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 	setData( weather.source, "Wind Gust", stringConverter(weather.windgusts) );
 	setData( weather.source, "Windchill", stringConverter(weather.windchill) );
 	
-	if( !weather.sLatitude.isEmpty() && !weather.sLongitude.isEmpty() )
+	if( !weather.latitude.isEmpty() && !weather.longitude.isEmpty() )
 	{
-		setData( weather.source, "Longitude", weather.sLongitude );
-		setData( weather.source, "Latitude", weather.sLatitude );
+		setData( weather.source, "Longitude", weather.longitude );
+		setData( weather.source, "Latitude", weather.latitude );
 	}
 
 	if( weather.vForecasts.count() > 0 )
@@ -909,7 +889,7 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 
 		if( weather.observationPeriode.isValid() )
 		{
-			KDateTime dateTime( currDate, weather.observationPeriode, KDateTime::Spec::OffsetFromUTC(weather.iUtcHourOffset) );
+			KDateTime dateTime( currDate, weather.observationPeriode, KDateTime::Spec::OffsetFromUTC(weather.utcHourOffset) );
 			if( dateTime.isValid() )
 				setData( weather.source, "Observation Period", dateTime.toString("%d.%m.%Y @ %H:%M") );
 		}
@@ -923,8 +903,8 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 			if( iWeekday >= 1 && iWeekday<=7 )
 				sDayName = i18n(vWeekdays[iWeekday-1]);
 
-			updateWeatherCondition( weather.source, iDay, sDayName, true, (*itDay)->DayTime );
-			updateWeatherCondition( weather.source, iDay, sDayName, false, (*itDay)->NightTime );
+			updateForecastCondition( weather.source, iDay, sDayName, true, (*itDay)->dayTime );
+			updateForecastCondition( weather.source, iDay, sDayName, false, (*itDay)->nightTime );
 
 			if( iDay > 0 )
 				updateSun( weather.source, iDay, sDayName, **itDay );
@@ -946,7 +926,7 @@ AccuWeatherIon::updateWeatherSource( const WeatherData & weather, const ImageDat
 }
 
 void
-AccuWeatherIon::updateWeatherCondition( const QString & source,
+AccuWeatherIon::updateForecastCondition( const QString & source,
                                         int iDayIndex,
                                         const QString & dayName,
                                         bool bDayTime,
@@ -1002,18 +982,36 @@ AccuWeatherIon::updateSun( const QString & source,
 \*********************************************************************************/
 
 QByteArray
-AccuWeatherIon::getImageUrl( const QString & sLocationCode ) const
+AccuWeatherIon::Private::getImageUrl( const QString & sLocationCode, const QString & state ) const
 {
 	QStringList lst = sLocationCode.split('|',QString::SkipEmptyParts);
 
 	//--- When lst contains just one entry, we assume it is a city in the United States ---
 	if (lst.count() == 1)
-		return QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/EI/iseun.jpg");
-
+	{
+		// this is the satellite map of the entire united states
+		//return QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/EI/iseun.jpg");
+		
+		QString url = QString("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/is%1_.jpg").arg(state.toLower());
+		return url.toLatin1();
+	}
+	
 	QByteArray sUrl;
 	
 	if (lst[0].compare("EUR") == 0)
-		sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/iseurm.jpg");
+	{
+		// this is the smaller map
+		//sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/iseurm.jpg");
+		
+		if (lst[1].compare("FI") == 0 ||
+		    lst[1].compare("SE") == 0 ||
+		    lst[1].compare("NO") == 0)
+		{
+			sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/iseurm.jpg");
+		}
+		else
+			sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/iseur3.jpg");
+	}
 	
 	else if (lst[0].compare("SAM") == 0)
 	{
@@ -1094,8 +1092,7 @@ AccuWeatherIon::connectWithImageData( const QByteArray & imageUrl )
 //			pJob->addMetaData("cookies", "none"); // Disable displaying cookies
 			pImageData = new ImageData;
 			pImageData->imageUrl = imageUrl;
-			pImageData->bReady = false;
-			pImageData->iLocationCounter = 1;
+			pImageData->ready = false;
 			d->vImageJobs.insert( pJob, pImageData );
 			d->vImageData.insert( imageUrl, pImageData );
 
@@ -1104,14 +1101,38 @@ AccuWeatherIon::connectWithImageData( const QByteArray & imageUrl )
 			connect(  pJob, SIGNAL(result(KJob *)), this, SLOT(image_slotJobFinished(KJob *)) );
 		}
 	}
-	else
-	{
-		pImageData = d->vImageData[imageUrl];
-		pImageData->iLocationCounter += 1;
-	}
 	dEndFunct();
 }
 
+void
+AccuWeatherIon::Private::removeAllImages()
+{
+	//--- when we do not need the image anymore and the image job has been completed remove the image data ---
+	if( vObservationJobs.count() == 0 && vImageJobs.count() == 0 )
+	{
+		QHash<QByteArray, ImageData *>::iterator itImg = vImageData.begin();
+		for( ; itImg != vImageData.end(); ++itImg)
+		{
+			ImageData * pImageData = itImg.value();
+			removeImageDataAttachedWeatherData( pImageData );
+			delete pImageData;
+		}
+		vImageData.clear();
+	}
+}
+
+void
+AccuWeatherIon::Private::removeImageDataAttachedWeatherData(ImageData * pImageData)
+{
+	QList<WeatherData*>::iterator itWeather = pImageData->vWeatherSources.begin();
+	for( ; itWeather != pImageData->vWeatherSources.end(); ++itWeather )
+	{
+		WeatherData * pWeather = *itWeather;
+		qDeleteAll( pWeather->vForecasts.begin(), pWeather->vForecasts.end() );
+		delete pWeather;
+	} 
+}
+
 void
 AccuWeatherIon::image_slotDataArrived( KIO::Job * pJob, const QByteArray & data )
 {
@@ -1125,9 +1146,11 @@ AccuWeatherIon::image_slotJobFinished( KJob * pJob )
 {
 	if( !d->vImageJobs.contains(pJob) )
 		return;
+	
 	dStartFunct();
+	
 	struct ImageData * pImageData = d->vImageJobs[pJob];
-	pImageData->bReady = true;
+	pImageData->ready = true;
 
 	if( pJob->error() == 0 )
 	{
@@ -1146,22 +1169,29 @@ AccuWeatherIon::image_slotJobFinished( KJob * pJob )
 		updateWeatherSource( *pWeather, pImageData );
 		qDeleteAll( pWeather->vForecasts.begin(), pWeather->vForecasts.end() );
 		delete pWeather;
-		pImageData->iLocationCounter -= 1;
 	}
 
 	d->vImageJobs.remove( pJob );
 	pJob->deleteLater();
-	if( pImageData->iLocationCounter <= 0 )
-	{
-		d->vImageData.remove( pImageData->imageUrl );
-		delete pImageData;
-	}
 
-	dDebug() << "Image Jobs: " << d->vImageJobs.count();
-	dDebug() << "Image Data: " << d->vImageData.count();
+	//--- remove all images when we have no active observation and image job ---
+	d->removeAllImages();
+
+	d->printJobStatistics();
 	dEndFunct();
 }
 
+void
+AccuWeatherIon::Private::printJobStatistics() const
+{
+	dDebug() << "Active Jobs: " << vActiveJobs.count();
+	dDebug() << "Search Jobs: " << vSearchJobs.count();
+	dDebug() << "Observation Jobs: " << vObservationJobs.count();
+	dDebug() << "Image Jobs: " << vImageJobs.count();
+	dDebug() << "Image Data: " << vImageData.count();
+
+}
+
 #if KDE_VERSION_MINOR >= 3
 	 K_EXPORT_PLASMA_DATAENGINE(accuweather, AccuWeatherIon);
 #else
