@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007-2008 by Shawn Starr <shawn.starr@rogers.com>       *
+ *   Copyright (C) 2009-2011 by  Ulf Kreißig <udev@gmx.net>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,25 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
  ***************************************************************************/
 
-/*************************************************************************\
-*   Copyright (C) 2009 by Ulf Kreissig                                    *
-*   udev@gmx.net                                                          *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
-\*************************************************************************/
+/*  The source code of this weather engine based on source code
+ *  of KDE's standard weather engines written by Shawn Starr.
+ */
 
 #ifndef ACCUWEATHER_ION_H
 #define ACCUWEATHER_ION_H
@@ -56,100 +41,100 @@
 
 struct XmlJobData
 {
-	QXmlStreamReader	xmlReader;
-	QString				sLocation;
-	QString				sSource;
+	QXmlStreamReader      xmlReader;
+	QString               location;
+	QString               source;
 
 	//--- just for observation jobs ---
-	QString				sLocationCode;
-	QByteArray			imageUrl;
+	QString               locationCode;
 };
 
 struct ForecastConditions
 {
-	QString			weathertext;
-	QString			weathericon;
-	QString			hightemperature;
-	QString			lowtemperature;
-	QString			realfeelhigh;
-	QString			realfeellow;
-	QString			windspeed;
-	QString			winddirection;
-	QString			windgust;
-	QString			uvIndex;
+	QString               weathertext;
+	QString               weathericon;
+	QString               hightemperature;
+	QString               lowtemperature;
+	QString               realfeelhigh;
+	QString               realfeellow;
+	QString               windspeed;
+	QString               winddirection;
+	QString               windgust;
+	QString               uvIndex;
 };
 
 struct ForecastDay
 {
-	QString			obsdate;
-	QString			sunrise;
-	QString			sunset;
+	QString               obsdate;
+	QString               sunrise;
+	QString               sunset;
 
-	ForecastConditions	DayTime;
-	ForecastConditions	NightTime;
+	ForecastConditions    dayTime;
+	ForecastConditions    nightTime;
 };
 
 struct WeatherData
 {
-	QString			source;
-	QString			locationCode;
-	QString			city;
+	QString               source;
+	QString               city;
+	QString               state;	// is needet for closer satellite map (at least for the states of the US)
 	
-	QString			forecastUrl;
+	QString               forecastUrl;
 
-	short			iUtcHourOffset;
-	short			iUtcMinutesOffset;
-	QTime			observationPeriode;
-	QString			sLatitude;
-	QString			sLongitude;
+	short                 utcHourOffset;
+	short                 utcMinutesOffset;
+	QTime                 observationPeriode;
+	QString               latitude;
+	QString               longitude;
 	
-	int				iDistanceSystem;
-	int				iPressureSystem;
-	int				iSpeedSystem;
-	int				iTempSystem;
+	int                   distanceSystem;
+	int                   pressureSystem;
+	int                   speedSystem;
+	int                   tempSystem;
 
-	QString			temperature;
-	QString			realfeel;
-	QString			humidity;
-	QString			weathertext;
-	QString			weathericon;
-	QString			windspeed;
-	QString			winddirection;
-	QString			windgusts;
-	QString			windchill;
-	QString			visibility;
-	QString			dewpoint;
-	QString			pressure;
-	QString			pressureTendency;
-	QString			uvIndex;
-	QString			uvRating;
+	QString               temperature;
+	QString               realfeelTemperature;
+	QString               humidity;
+	QString               weathertext;
+	QString               weathericon;
+	QString               windspeed;
+	QString               winddirection;
+	QString               windgusts;
+	QString               windchill;
+	QString               visibility;
+	QString               dewpoint;
+	QString               pressure;
+	QString               pressureTendency;
+	QString               uvIndex;
+	QString               uvRating;
 
-	QList<ForecastDay *>	vForecasts;
+	QList<ForecastDay *>  vForecasts;
 };
 
 struct ImageData
 {
-	QByteArray				fetchedData;
-	QByteArray				imageUrl;
-	QImage					image;
+	QByteArray            fetchedData;
+	QByteArray            imageUrl;
+	QImage                image;
 
-	/*  Every time, a weather job is ready, we check if the image job is ready as well in order to
-	 *  order to update the source:
-	 *  ImageJob is ready:	update source immedatly and delete the weatherData in the list
-	 *                        since we do not need them anymore
-	 *  otherwise:			we add the weatherData to the list vWeatherSources.
-	 *                         When imagejob is ready, than we will update all locations in this list,
-	 *                         delete the job and keep the source until all weather has been updated.
+	/*  Every time, a weather job is ready, we check if the image job is ready as well
+	 *  in order to update the source:
+	 *  ImageJob is ready:
+	 *      update source immedatly and delete the weatherData in the list
+	 *      since we do not need them anymore
+	 *  otherwise:
+	 *      we add the weatherData to the list vWeatherSources.
+	 *      When imagejob is ready, than we will update all locations in this list,
+	 *      Delete the job and keep the image-source until all weather-jobs has been updated.
+	 *
+	 *  The image data will be remove when there is no active weather-data and satellite job anymore.
 	 */
-	bool					bReady;
-
-	/*  counter of all cities that relay on this image are not ready yet */
-	int						iLocationCounter;
+	bool                  ready;
 
 	/*  List contains the data of location where the job has been already completed
 	 *  and the data are just waiting for the ImageJob to update.
 	 */
-	QList<WeatherData *>	vWeatherSources;
+	QList<WeatherData *>  vWeatherSources;
 };
 
 
@@ -209,16 +194,16 @@ private:
 	void readWeatherConditions( QXmlStreamReader & xml, ForecastConditions & conditions );
 
 	//--- image functions ---
-	QByteArray getImageUrl( const QString & sLocationCode ) const;
 	void connectWithImageData( const QByteArray & imageUrl );
 
 	//--- update stuff ---
 	void updateWeatherSource( const WeatherData & weather, const ImageData * pImageData );
-	void updateWeatherCondition( const QString & source,
-	                             int iDayIndex,
-	                             const QString & dayName,
-	                             bool bDayTime,
-	                             const ForecastConditions & conditions );
+	void updateForecastCondition(
+		const QString & source,
+		int iDayIndex,
+		const QString & dayName,
+		bool bDayTime,
+		const ForecastConditions & conditions );
 	void updateSun( const QString & source, int iDayIndex, const QString & dayName, const ForecastDay & day );
 
 	inline QString stringConverter( const QString & sValue ) const { return sValue.isEmpty() ? "N/A" : sValue; }
