@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007-2008 by Shawn Starr <shawn.starr@rogers.com>       *
+ *   Copyright (C) 2009-2011 by  Ulf Kreißig <udev@gmx.net>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,25 +18,11 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
  ***************************************************************************/
 
-/*************************************************************************\
-*   Copyright (C) 2009 by  Ulf Kreißig                                    *
-*   udev@gmx.net                                                          *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
-\*************************************************************************/
+/*  The source code of this weather engine based on source code
+ *  of KDE's standard weather engines written by Shawn Starr.
+ */
+
+#define MAX_FORECAST_DAY 6
 
 //--- LOCAL ---
 #include "../config.h"
@@ -112,8 +99,7 @@ struct XmlWeatherData
 	QString sLocation;
 	
 	QString sCurrentIcon;
-	QString sDayCondition;
-	QString sNightCondition;
+	QString sCondition;
 	QString sHumidity;
 	QString sWindDirection;
 	QString sWindSpeed;
@@ -131,7 +117,7 @@ struct XmlWeatherData
 	QString sLatitude;
 	QString sTimeZone;
 
-	QList<XmlForecastDay *> vForecasts;
+	XmlForecastDay vForecasts[MAX_FORECAST_DAY];
 	
 	/*  Weather information are splitted in different xml-files: current_observation, forecast, alerts.
 	 *  We will return the results to the widget, when all jobs have been completed.
@@ -185,16 +171,20 @@ struct WundergroundIon::Private
 	QStringList                       sourcesToReset;
 #endif
 	
-	void setup_readStation( const QString & sLocation,
-	                        const WeatherStationType type,
-	                        QXmlStreamReader & xml,
-	                        XmlLookupResult * pResult );
-	XmlForecastDay * parseForecastDay( QXmlStreamReader & xml,
-	                                   const KLocale::MeasureSystem measureSystem,
-	                                   QString & sTimeZone ) const;
-	QString parseForecastTemp( QXmlStreamReader & xml,
-	                           const KLocale::MeasureSystem measureSystem ) const;
-	void parseTextCondition( QXmlStreamReader & xml, XmlWeatherData & data ) const;
+	void setup_readStation(
+		const QString & sLocation,
+		const WeatherStationType type,
+		QXmlStreamReader & xml,
+		XmlLookupResult * pResult );
+	
+	void parseForecastDay(
+		QXmlStreamReader & xml,
+		XmlWeatherData & data) const;
+	
+	QString parseForecastTemp(
+		QXmlStreamReader & xml,
+		const KLocale::MeasureSystem measureSystem ) const;
+	
 	QTime parseTime( QXmlStreamReader & xml ) const;
 	
 	inline QString stringConverter( const QString & sValue ) const
@@ -302,9 +292,7 @@ WundergroundIon::cleanup()
 	QHash<QString, XmlWeatherData *>::iterator itWeather;
 	for( itWeather = d->vWeatherData.begin(); itWeather != d->vWeatherData.end(); ++itWeather )
 	{
-		XmlWeatherData * pWeather = itWeather.value();
-		qDeleteAll(pWeather->vForecasts.begin(), pWeather->vForecasts.end());
-		delete pWeather;
+		delete itWeather.value();
 	}
 	d->vWeatherData.clear();
 	
@@ -657,7 +645,6 @@ WundergroundIon::slotJobFinished( KJob * job )
 				updateWeatherSource( *pWeatherData, pImageData );
 				
 				d->vWeatherData.remove(pXmlData->sServiceId);
-				qDeleteAll(pWeatherData->vForecasts.begin(), pWeatherData->vForecasts.end());
 				delete pWeatherData;
 				
 				if (pImageData)
@@ -719,7 +706,6 @@ WundergroundIon::slotImageJobFinished( KJob * pJob )
 	{
 		XmlWeatherData * pWeather = pImageData->vWeatherSources.takeFirst();
 		updateWeatherSource( *pWeather, pImageData );
-		qDeleteAll( pWeather->vForecasts.begin(), pWeather->vForecasts.end() );
 		delete pWeather;
 		pImageData->locationCounter -= 1;
 	}
@@ -841,7 +827,13 @@ WundergroundIon::readCurrentObservation( QXmlStreamReader & xml, XmlWeatherData
 {
 	dStartFunct();
 
-	short iLevel(0);
+	short iLevel = 0;
+	bool bDisplayLocation = false;
+	bool bObservationLocation = false;
+	
+	QString sLongitude;
+	QString sLatitude;
+	
 	while( !xml.atEnd() )
 	{
 		xml.readNext();
@@ -858,43 +850,10 @@ WundergroundIon::readCurrentObservation( QXmlStreamReader & xml, XmlWeatherData
 					data.sObservationTime = xml.readElementText();
 				else if( xml.name().compare("forecast_url") == 0 )
 					data.sForecastUrl = xml.readElementText();
-				
-				// we try to extract the longitude and latitude for the weather image,
-				// the longitude & latitude does not match the position information
-				// we receive in tag <observation_location>
-				else if( xml.name().compare("ob_url") == 0 )
-				{
-					QString sTmp = xml.readElementText();
-					dInfo() << "Latitude/Longitude" << sTmp;
-					int pos = sTmp.indexOf("?query=");
-					sTmp = sTmp.right(sTmp.length() - pos - 7); // we do not want the text "?query=" in text
-					QStringList vPosition = sTmp.split(',', QString::SkipEmptyParts);
-					dInfo() << "Latitude/Longitude for image" << vPosition;
-					
-					if (vPosition.length() == 2)
-					{
-						QUrl urlSatelliteMap("http://wublast.wunderground.com/cgi-bin/WUBLAST");
-						urlSatelliteMap.addEncodedQueryItem("lat", vPosition[0].toLatin1());
-						urlSatelliteMap.addEncodedQueryItem("lon", vPosition[1].toLatin1());
-						urlSatelliteMap.addEncodedQueryItem("zoom", "3");
-						urlSatelliteMap.addEncodedQueryItem("width", "310");
-						urlSatelliteMap.addEncodedQueryItem("height", "233");
-						urlSatelliteMap.addEncodedQueryItem("key", "sat_ir4_thumb");
-						urlSatelliteMap.addEncodedQueryItem("basemap", "1");
-						urlSatelliteMap.addEncodedQueryItem("gtt", "0");
-						urlSatelliteMap.addEncodedQueryItem("num", "1");
-						urlSatelliteMap.addEncodedQueryItem("timelabel", "0");
-						urlSatelliteMap.addEncodedQueryItem("delay", "25");
-						urlSatelliteMap.addEncodedQueryItem("borders", "1");
-						urlSatelliteMap.addEncodedQueryItem("theme", "WUNIDS");
-						urlSatelliteMap.addEncodedQueryItem("extension", "png");
-
-						dInfo() << "Satellite Map" << urlSatelliteMap;
-						data.imageUrl = urlSatelliteMap;
-						
-						connectWithImageData(urlSatelliteMap);
-					}
-				}
+				else if (xml.name().compare("display_location") == 0)
+					bDisplayLocation = true;
+				else if (xml.name().compare("observation_location") == 0)
+					bObservationLocation = true;
 				else if( xml.name().compare("relative_humidity") == 0 )
 				{
 					data.sHumidity = xml.readElementText().simplified();
@@ -913,8 +872,10 @@ WundergroundIon::readCurrentObservation( QXmlStreamReader & xml, XmlWeatherData
 				else if( xml.name().compare("wind_gust_mph") == 0 )
 					data.sWindGust = xml.readElementText();
 				else if( xml.name().compare("icon") == 0 )
-					data.sCurrentIcon = getWeatherIcon(d->vIconConditionMap, xml.readElementText());
-				
+					data.sCurrentIcon = xml.readElementText();
+				else if( xml.name().compare("weather") == 0 )
+					data.sCondition = xml.readElementText();
+
 				if( data.measureSystem == KLocale::Metric )
 				{
 					if( xml.name().compare("temp_c") == 0 )
@@ -938,17 +899,53 @@ WundergroundIon::readCurrentObservation( QXmlStreamReader & xml, XmlWeatherData
 						data.sVisibility = xml.readElementText();
 				}
 			}
-			else if( iLevel == 2 )
+
+			else if(bDisplayLocation || bObservationLocation)
 			{
 				if( xml.name().compare("longitude") == 0 )
-					data.sLongitude = xml.readElementText();
+					sLongitude = xml.readElementText();
 				else if( xml.name().compare("latitude") == 0 )
-					data.sLatitude = xml.readElementText();
+					sLatitude = xml.readElementText();
 			}
 			iLevel += 1;
 		}
 		if( xml.isEndElement() )
 		{
+			if (iLevel == 2 && xml.name().compare("display_location") == 0)
+			{
+				bDisplayLocation = false;
+				
+				data.sLongitude = sLongitude;
+				data.sLatitude = sLatitude;
+			}
+			else if (iLevel == 2 && xml.name().compare("observation_location") == 0)
+			{
+				bObservationLocation = false;
+				
+				if (!sLatitude.isEmpty() && !sLongitude.isEmpty())
+				{
+					QUrl urlSatelliteMap("http://wublast.wunderground.com/cgi-bin/WUBLAST");
+					urlSatelliteMap.addEncodedQueryItem("lat", sLatitude.toLatin1());
+					urlSatelliteMap.addEncodedQueryItem("lon", sLongitude.toLatin1());
+					urlSatelliteMap.addEncodedQueryItem("zoom", "3");
+					urlSatelliteMap.addEncodedQueryItem("width", "310");
+					urlSatelliteMap.addEncodedQueryItem("height", "233");
+					urlSatelliteMap.addEncodedQueryItem("key", "sat_ir4_thumb");
+					urlSatelliteMap.addEncodedQueryItem("basemap", "1");
+					urlSatelliteMap.addEncodedQueryItem("gtt", "0");
+					urlSatelliteMap.addEncodedQueryItem("num", "1");
+					urlSatelliteMap.addEncodedQueryItem("timelabel", "0");
+					urlSatelliteMap.addEncodedQueryItem("delay", "25");
+					urlSatelliteMap.addEncodedQueryItem("borders", "1");
+					urlSatelliteMap.addEncodedQueryItem("theme", "WUNIDS");
+					urlSatelliteMap.addEncodedQueryItem("extension", "png");
+
+					dInfo() << "Satellite Map" << urlSatelliteMap;
+					data.imageUrl = urlSatelliteMap;
+					
+					connectWithImageData(urlSatelliteMap);
+				}
+			}
 			iLevel -= 1;
 		}
 	}
@@ -964,6 +961,7 @@ WundergroundIon::connectWithImageData(const QUrl & urlSatelliteMap)
 	{
 		dWarning() << "Url for satellite map is empty";
 		dEndFunct();
+		return;
 	}
 	
 	ImageData * pImageData = 0;
@@ -1003,8 +1001,7 @@ WundergroundIon::readWeatherForecast( QXmlStreamReader & xml, XmlWeatherData & d
 	dStartFunct();
 	
 	short iLevel(0);
-	bool bCurrentCondition(false);
-	bool bForecast(false);
+	bool bForecast = false;
 	bool bMoonPhase(false);
 	while( !xml.atEnd() )
 	{
@@ -1019,24 +1016,13 @@ WundergroundIon::readWeatherForecast( QXmlStreamReader & xml, XmlWeatherData & d
 			}
 			else if( iLevel == 1 )
 			{
-				if( xml.name().compare("txt_forecast") == 0 )
-					bCurrentCondition = true;
-				else if( xml.name().compare("simpleforecast") == 0 )
+				if( xml.name().compare("simpleforecast") == 0 )
 					bForecast = true;
 				else if( xml.name().compare("moon_phase") == 0 )
 					bMoonPhase = true;
 			}
-			else if( bCurrentCondition && xml.name().compare("forecastday") == 0 )
-				d->parseTextCondition(xml, data);
 			else if( bForecast && xml.name().compare("forecastday") == 0 )
-			{
-				XmlForecastDay * pForecast = d->parseForecastDay(xml, data.measureSystem, data.sTimeZone);
-				if( pForecast )
-				{
-					pForecast->sIcon = getWeatherIcon(d->vIconConditionMap, pForecast->sIcon);
-					data.vForecasts.append(pForecast);
-				}
-			}
+				d->parseForecastDay(xml, data);
 			else if( bMoonPhase )
 			{
 				if( xml.name().compare("sunrise") == 0 )
@@ -1049,8 +1035,6 @@ WundergroundIon::readWeatherForecast( QXmlStreamReader & xml, XmlWeatherData & d
 		if( xml.isEndElement() )
 		{
 			iLevel -= 1;
-			if( bCurrentCondition && xml.name().compare("txt_forecast") == 0 )
-				bCurrentCondition = false;
 			if( bForecast && xml.name().compare("simpleforecast") == 0 )
 				bForecast = false;
 			else if( bMoonPhase && xml.name().compare("moon_phase") == 0 )
@@ -1088,9 +1072,12 @@ WundergroundIon::updateWeatherSource( const XmlWeatherData & data, const ImageDa
 
 	/*** Convert the obervation time to locale time and add the formated time string to data-container */
 	if( !data.sObservationTime.isEmpty() &&
-	    data.sObservationTime.compare("NA") !=0 && data.sObservationTime.compare("N/A") !=0 )
+	    data.sObservationTime.compare("NA") !=0 &&
+	    data.sObservationTime.compare("N/A") !=0 )
 	{
-		obsDate = KDateTime::fromString(data.sObservationTime, "%A, %e %B %Y %H:%M:%S %Z", KSystemTimeZones::timeZones(), true);
+		obsDate = KDateTime::fromString(data.sObservationTime, "%:A, %e %:B %Y %H:%M:%S %Z", KSystemTimeZones::timeZones(), true);
+		if (!obsDate.isValid())
+			obsDate = KDateTime::fromString(data.sObservationTime, "%:a, %e %:b %Y %H:%M:%S %Z", KSystemTimeZones::timeZones(), true);
 		if( obsDate.isValid() && !data.sTimeZone.isEmpty() )
 		{
 			obsDate = obsDate.toZone( KSystemTimeZones::zone(data.sTimeZone) );
@@ -1140,7 +1127,7 @@ WundergroundIon::updateWeatherSource( const XmlWeatherData & data, const ImageDa
 	setData(data.sSource, "Wind Speed Unit",  QString::number(iSpeedSystem) );
 
 	setData(data.sSource, "Condition Icon", getWeatherIcon(d->vIconConditionMap, d->stringConverter(data.sCurrentIcon) ) );
-	setData(data.sSource, "Current Conditions", d->stringConverter(data.sDayCondition) );
+	setData(data.sSource, "Current Conditions", d->stringConverter(data.sCondition) );
 
 	setData(data.sSource, "Dewpoint", d->stringConverter(data.sDewpoint) );
 	setData(data.sSource, "Humidity", d->stringConverter(data.sHumidity) );
@@ -1175,45 +1162,42 @@ WundergroundIon::updateWeatherSource( const XmlWeatherData & data, const ImageDa
 				.arg(dateTime.date().year())
 				.arg(dateTime.toString("HH:mm")));
 		}
+		else
+			dError() << "observation date is invalid";
 #endif
 	}
-	if( data.vForecasts.count() > 0 )
+
+	short dayIndex = 0;
+	while (dayIndex < MAX_FORECAST_DAY)
 	{
-		setData(data.sSource, "Total Weather Days", QString::number(data.vForecasts.count()) );
+		const XmlForecastDay * pDay = &data.vForecasts[dayIndex];
+		if (pDay->sDayName.isEmpty())
+			break;
 		
-		QList<XmlForecastDay *>::const_iterator itDay = data.vForecasts.constBegin();
-		short iDay(0);
-		for( ; itDay != data.vForecasts.constEnd(); ++itDay, ++iDay )
-		{
-			const QString * psCurrCondition = NULL;
-			if( iDay == 0 && obsDate.isValid() && data.sunrise.isValid() && data.sunset.isValid() )
-			{
-				QTime obsTime( obsDate.time() );
-				if( data.sunrise < obsTime && obsTime < data.sunset )
-					psCurrCondition = (data.sDayCondition.isEmpty() ? NULL : &data.sDayCondition);
-				else
-					psCurrCondition = (data.sNightCondition.isEmpty() ? NULL : &data.sNightCondition);
-			}
-			setData( data.sSource,
-					 QString("Short Forecast Day %1").arg(iDay),
-					QString("%1|%2|%3|%4|%5|N/A")
-						.arg( (*itDay)->sDayName )
-						.arg( d->stringConverter((*itDay)->sIcon) )
-						.arg( d->stringConverter( psCurrCondition ? *psCurrCondition : (*itDay)->sDescription) )
-						.arg( d->stringConverter((*itDay)->sHighTemp) )
-						.arg( d->stringConverter((*itDay)->sLowTemp) ) );
-		}
+		setData( data.sSource,
+				  QString("Short Forecast Day %1").arg(dayIndex),
+				QString("%1|%2|%3|%4|%5|N/A")
+					.arg( pDay->sDayName )
+					.arg( getWeatherIcon(d->vIconConditionMap, pDay->sIcon) )
+					.arg( d->stringConverter(pDay->sDescription) )
+					.arg( d->stringConverter(pDay->sHighTemp) )
+					.arg( d->stringConverter(pDay->sLowTemp) ) );
+		
+		dayIndex += 1;
 	}
+	if (dayIndex > 0)
+		setData(data.sSource, "Total Weather Days", QString::number(dayIndex) );
+
 	dEndFunct();
 }
 
 
 void
-WundergroundIon::Private::setup_readStation( const QString & sLocation,
-                                             const WeatherStationType stationType,
-                                             QXmlStreamReader & xml,
-                                             XmlLookupResult * pLookupResult )
-
+WundergroundIon::Private::setup_readStation(
+	const QString & sLocation,
+	const WeatherStationType stationType,
+	QXmlStreamReader & xml,
+	XmlLookupResult * pLookupResult )
 {
 	QString sCity;
 	QString sNeighborhood;
@@ -1323,45 +1307,64 @@ WundergroundIon::Private::setup_readStation( const QString & sLocation,
 
 }
 
-XmlForecastDay *
-WundergroundIon::Private::parseForecastDay( QXmlStreamReader & xml,
-                                            const KLocale::MeasureSystem system,
-                                            QString & sTimeZone ) const
+void
+WundergroundIon::Private::parseForecastDay(
+	QXmlStreamReader & xml,
+	XmlWeatherData & data) const
 {
-	XmlForecastDay * pDay = new XmlForecastDay;
+	int dayIndex = -1;
+	QString sDayName;
+	QString sDescription;
+	QString sIcon;
+	QString sHighTemp;
+	QString sLowTemp;
 	
 	short iLevel = 1;	// we have parsed the start tag already, and decided to call this function!!!
-//	short iPeriod = 0;
 	
-	while( !xml.atEnd() )
+	while (!xml.atEnd())
 	{
 		xml.readNext();
 		if( xml.isStartElement() )
 		{
-//			if( xml.name().compare("period") == 0 )
-//				iPeriod = xml.readElementText().toInt();
+			if( xml.name().compare("period") == 0 )
+				dayIndex = xml.readElementText().toInt();
 			if( xml.name().compare("weekday") == 0 )
-				pDay->sDayName = i18n(xml.readElementText().left(3).toUtf8().constData());
+				sDayName = i18n(xml.readElementText().left(3).toUtf8().constData());
 			else if( xml.name().compare("tz_long") == 0 )
-				sTimeZone = xml.readElementText();
+			{
+				QString sTimeZone = xml.readElementText();
+				if (data.sTimeZone.isEmpty())
+					data.sTimeZone = sTimeZone;
+			}
 			else if( xml.name().compare("conditions") == 0 )
-				pDay->sDescription = QUrl::fromPercentEncoding(xml.readElementText().toUtf8());
+				sDescription = QUrl::fromPercentEncoding(xml.readElementText().toUtf8());
 			else if( xml.name().compare("icon") == 0 )
-				pDay->sIcon = xml.readElementText();
+				sIcon = xml.readElementText();
 			else if( xml.name().compare("high") == 0 )
-				pDay->sHighTemp = parseForecastTemp(xml, system);
+				sHighTemp = parseForecastTemp(xml, data.measureSystem);
 			else if( xml.name().compare("low") == 0 )
-				pDay->sLowTemp = parseForecastTemp(xml, system);
+				sLowTemp = parseForecastTemp(xml, data.measureSystem);
 			iLevel += 1;
 		}
 		if( xml.isEndElement() )
 		{
 			iLevel -= 1;
 			if( xml.name().compare("forecastday") == 0 )
+			{
+				// dayIndex = 1 contains the data for TODAY !?
+				if (dayIndex > 0 && dayIndex <= MAX_FORECAST_DAY)
+				{
+					XmlForecastDay * pDay = &data.vForecasts[dayIndex-1];
+					pDay->sDayName = sDayName;
+					pDay->sDescription = sDescription;
+					pDay->sIcon = sIcon;
+					pDay->sHighTemp = sHighTemp;
+					pDay->sLowTemp = sLowTemp;
+				}
 				break;
+			}
 		}
 	}
-	return pDay;
 }
 
 QString
@@ -1391,48 +1394,6 @@ WundergroundIon::Private::parseForecastTemp( QXmlStreamReader & xml, const KLoca
 	return sTemp;
 }
 
-void
-WundergroundIon::Private::parseTextCondition( QXmlStreamReader & xml, XmlWeatherData & data ) const
-{
-	short   iLevel(1);
-	short   iPeriode(-1);
-	QString sText;
-	QString sIcon;
-	QDate   date;
-	
-	while( !xml.atEnd() )
-	{
-		xml.readNext();
-		if( xml.isStartElement() )
-		{
-			if( xml.name().compare("period") == 0 )
-				iPeriode = xml.readElementText().toShort();
-			else if( xml.name().compare("fcttext") == 0 )
-				sText = xml.readElementText();
-			else if(xml.name().compare("icon") == 0 )
-				sIcon = xml.readElementText();
-			else if( xml.name().compare("title") == 0 )
-				date = QDate::fromString(xml.readElementText(), "MMMM d, yyyy");
-			iLevel += 1;
-		}
-		if( xml.isEndElement() )
-		{
-			iLevel -= 1;
-			if( xml.name().compare("forecastday") == 0 )
-				break;
-		}
-	}
-	
-	dDebug() << "Forecast Condition Period: " << iPeriode << sIcon << sText;
-	if( !sText.isEmpty() &&
-	    date.isValid() &&
-	    iPeriode == 0 )
-	{
-		data.sDayCondition = sText;
-		data.sCurrentIcon = sIcon;
-	}
-}
-
 QTime
 WundergroundIon::Private::parseTime( QXmlStreamReader & xml ) const
 {
