@@ -61,7 +61,6 @@
 
 
 #include "streamlogger.h"
-#include "streamlogger_definitions.h"
 
 #include <QCoreApplication>
 #include <QIODevice>
@@ -82,6 +81,8 @@
 
 
 #ifdef ENABLE_DSTREAMLOGGER
+#include "streamlogger_definitions.h"
+
 DStreamLogger::MessageType DStreamLogger::m_logLevel(DEFAULT_LOGLEVEL);
 QCache<quintptr, DStreamLogger::TabInfo> DStreamLogger::m_vTabInfo(100);
 #endif
@@ -91,21 +92,21 @@ DStreamLogger::DStreamLogger( MessageType type,
                               const char * filename,
                               int iLine,
                               const char * funcinfo,
-			      signed short iTabSwitch )
+                              signed short iTabSwitch )
 	: QObject(NULL)
 #ifdef ENABLE_DSTREAMLOGGER
 	, stream(NULL)
 #endif
 {
 #ifdef ENABLE_DSTREAMLOGGER
-	if( iTabSwitch < 0 )
+	if (iTabSwitch < 0 && m_logLevel == Tracing)
 		tabLeft();
-	if( type >= m_logLevel )
+	if (type >= m_logLevel)
 	{
 		stream = createStream(type, logfile);
 		stream->createHeader(this, filename, iLine, funcinfo);
 	}
-	if( iTabSwitch > 0 )
+	if (iTabSwitch > 0 && m_logLevel == Tracing)
 		  tabRight();
 #else
 	Q_UNUSED(type)
@@ -121,21 +122,22 @@ DStreamLogger::DStreamLogger( MessageType type,
                               QIODevice * device,
                               const char * filename,
                               int iLine,
-                              const char * funcinfo, signed short iTabSwitch )
+                              const char * funcinfo,
+                              signed short iTabSwitch )
 	: QObject(NULL)
 #ifdef ENABLE_DSTREAMLOGGER
 	  , stream(NULL)
 #endif
 {
 #ifdef ENABLE_DSTREAMLOGGER
-	if( iTabSwitch < 0 )
+	if (iTabSwitch < 0 && m_logLevel == Tracing)
 		tabLeft();
-	if( type >= m_logLevel )
+	if (type >= m_logLevel)
 	{
 		stream = new Stream(type, device);
 		stream->createHeader(this, filename, iLine, funcinfo);
 	}
-	if( iTabSwitch > 0 )
+	if (iTabSwitch > 0 && m_logLevel == Tracing)
 		tabRight();
 #else
 	Q_UNUSED(type)
@@ -158,14 +160,14 @@ DStreamLogger::DStreamLogger( MessageType type,
 #endif
 {
 #ifdef ENABLE_DSTREAMLOGGER
-	if( iTabSwitch < 0 )
+	if (iTabSwitch < 0 && m_logLevel == Tracing)
 		tabLeft();
-	if( type >= m_logLevel )
+	if (type >= m_logLevel)
 	{
 		stream = createStream(type, LOGOUTPUT);
 		stream->createHeader(this, filename, iLine, funcinfo);
 	}
-	if( iTabSwitch > 0 )
+	if (iTabSwitch > 0 && m_logLevel == Tracing)
 		tabRight();
 #else
 	Q_UNUSED(type)
@@ -234,7 +236,7 @@ DStreamLogger::Stream::createHeader( const QObject * pParent, const char * fileN
 		switch (msgType)
 		{
 		case Tracing:  ts <<         "Tracing   "; break;
-		case Debug:	   ts <<         "Debug     "; break;
+		case Debug:    ts <<         "Debug     "; break;
 		case Info:     ts << "\033[36mInfo      \033[m"; break;
 		case Warning:  ts << "\033[33mWarning   \033[m"; break;
 		case Critical: ts << "\033[35mCritical  \033[m"; break;
