@@ -91,8 +91,6 @@
 #ifndef DSTREAMLOGGER_H
 #define DSTREAMLOGGER_H
 
-#include "streamlogger_definitions.h"
-
 //--- QT4 ---
 #include <QCache>
 #include <QDate>
@@ -127,13 +125,48 @@ private:
 	struct Stream
 	{
 		Stream(MessageType msgtype, QIODevice * device)
-			: file(),ts(device),msgType(msgtype),bSpace(true),iRef(1),outputType(Unknown),iTabSwitch(0) {}
+			: file(),
+			  ts(device),
+			  msgType(msgtype),
+			  bSpace(true),
+			  iRef(1),
+			  outputType(Unknown),
+			  iTabSwitch(0)
+		{
+		}
+		
 		Stream(MessageType msgtype, QString * buf)
-			: file(),ts(buf, QIODevice::WriteOnly),msgType(msgtype),bSpace(true),iRef(1),outputType(Unknown),iTabSwitch(0) {}
+			: file(),
+			  ts(buf, QIODevice::WriteOnly),
+			  msgType(msgtype),
+			  bSpace(true),
+			  iRef(1),
+			  outputType(Unknown),
+			  iTabSwitch(0)
+		{
+		}
+		
 		Stream(MessageType msgtype, OutputType outType)
-			: file(),ts(&buffer, QIODevice::WriteOnly),msgType(msgtype),bSpace(true),iRef(1),outputType(outType),iTabSwitch(0) {}
+			: file(),
+			  ts(&buffer, QIODevice::WriteOnly),
+			  msgType(msgtype),
+			  bSpace(true),
+			  iRef(1),
+			  outputType(outType),
+			  iTabSwitch(0)
+		{
+		}
+		
 		Stream(MessageType msgtype, const QString & logfile)
-			: file(logfile),ts(&buffer, QIODevice::WriteOnly),msgType(msgtype),bSpace(true),iRef(1),outputType(File),iTabSwitch(0) {}
+			: file(logfile),
+			  ts(&buffer, QIODevice::WriteOnly),
+			  msgType(msgtype),
+			  bSpace(true),
+			  iRef(1),
+			  outputType(File),
+			  iTabSwitch(0)
+		{
+		}
 
 		void createHeader( const QObject * parent, const char * fileName, int line, const char * funcinfo );
 
@@ -152,14 +185,15 @@ private:
 		TabInfo() : iSpacer(0) {}
 		unsigned short   iSpacer;
 	};
-
-	static QCache<quintptr, TabInfo>   m_vTabInfo;
 	
+	static Stream * createStream(MessageType type, const QString & logfile);
+
 	void tabRight();
 	void tabLeft();
 
 	QMutex   mutex;
 	Stream * stream;
+	static QCache<quintptr, TabInfo>   m_vTabInfo;
 
 #endif
 	static MessageType                 m_logLevel;
@@ -168,12 +202,26 @@ public:
 	static inline void setLogLevel(MessageType level) {m_logLevel = level;}
 	static inline MessageType logLevel() {return m_logLevel;}
 
-	DStreamLogger( MessageType type, const QString & logfile,
-				   const char * fileName, int line, const char * funcinfo, signed short = 0 );
-	DStreamLogger( MessageType type, QIODevice * device,
-				   const char * fileName, int line, const char * funcinfo, signed short = 0 );
 	DStreamLogger( MessageType type,
-				   const char * fileName, int line, const char * funcinfo, signed short = 0  );
+	               const QString & logfile,
+	               const char * fileName,
+	               int line,
+	               const char * funcinfo,
+	               signed short = 0 );
+	
+	DStreamLogger( MessageType type,
+	               QIODevice * device,
+	               const char * fileName,
+	               int line,
+	               const char * funcinfo,
+	               signed short = 0 );
+	
+	DStreamLogger( MessageType type,
+	               const char * fileName,
+	               int line,
+	               const char * funcinfo,
+	               signed short = 0 );
+	
 	inline DStreamLogger(const DStreamLogger & o)
 		: QObject(NULL)
 #ifdef ENABLE_DSTREAMLOGGER
@@ -695,15 +743,15 @@ DStreamLogger operator<<(DStreamLogger debug, const QVariant & v)
 
 /***  THIS IS THE PUBLIC SCOPE OF OPERATION, THAT THIS LOGSYSTEM IS OFFERING FOR DEBUG  ***
  */
-#define dTracing()    DStreamLogger(DStreamLogger::Tracing,  LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
-#define dDebug()      DStreamLogger(DStreamLogger::Debug,    LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
-#define dInfo()       DStreamLogger(DStreamLogger::Info,     LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
-#define dWarning()    DStreamLogger(DStreamLogger::Warning,  LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
-#define dCritical()   DStreamLogger(DStreamLogger::Critical, LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
-#define dError()      DStreamLogger(DStreamLogger::Error,    LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO)
+#define dTracing()    DStreamLogger(DStreamLogger::Tracing,  __FILE__, __LINE__, Q_FUNC_INFO)
+#define dDebug()      DStreamLogger(DStreamLogger::Debug,    __FILE__, __LINE__, Q_FUNC_INFO)
+#define dInfo()       DStreamLogger(DStreamLogger::Info,     __FILE__, __LINE__, Q_FUNC_INFO)
+#define dWarning()    DStreamLogger(DStreamLogger::Warning,  __FILE__, __LINE__, Q_FUNC_INFO)
+#define dCritical()   DStreamLogger(DStreamLogger::Critical, __FILE__, __LINE__, Q_FUNC_INFO)
+#define dError()      DStreamLogger(DStreamLogger::Error,    __FILE__, __LINE__, Q_FUNC_INFO)
 
-#define dStartFunct() DStreamLogger(DStreamLogger::Tracing,  LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO,  1) << "[function starts]"
-#define dEndFunct()   DStreamLogger(DStreamLogger::Tracing,  LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO, -1) << "[function ends]"
+#define dStartFunct() DStreamLogger(DStreamLogger::Tracing,  __FILE__, __LINE__, Q_FUNC_INFO,  1) << "[function starts]"
+#define dEndFunct()   DStreamLogger(DStreamLogger::Tracing,  __FILE__, __LINE__, Q_FUNC_INFO, -1) << "[function ends]"
 
 /*#define D_ASSERT( cond, where, what ) \
 	if(!(cond)) {DStreamLogger(DStreamLogger::Error,  LOGOUTPUT, __FILE__, __LINE__, Q_FUNC_INFO).nospace() << "ASSERT failure in " << where << ": " << what; exit(-1);}
