@@ -1,6 +1,5 @@
 /*************************************************************************\
-*   Copyright (C) 2009 by                                     *
-*                                                             *
+*   Copyright (C) 2009-2011 by  Ulf Kreißig <udev@gmx.net>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -21,10 +20,6 @@
 #ifndef IONTEST_H
 #define IONTEST_H
 
-//--- LOCAL ---
-#include "ions/ion_accuweather.h"
-//#include "ions/ion_google.h"
-
 //--- QT4 ---
 #include <QObject>
 
@@ -48,8 +43,7 @@ public slots:
 	void quit();
 
 private:
-	AccuWeatherIon  m_ion;
-//	GoogleIon	m_ion;
+	IonInterface * m_pIon;
 };
 
 #endif // IONTEST_H
